==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/fi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Ensimmäisen käyttökerran avustaja",
    "Add your profile information! For example your email is needed to reset your password." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan salasanan palauttamiseen.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva ja koko nimi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää koko nimesi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva, jotta sinut on helpompi tunnistaa.",
    "About" : "Tietoja",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloudin ensimmäisen käyttökerran avustaja",
    "Previous" : "Edellinen",
    "Next" : "Seuraava",
    "Close" : "Sulje",
    "Start using Nextcloud" : "Aloita Nextcloudin käyttäminen",
    "Extend your cloud" : "Laajenna pilveäsi",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Löydä yli 100 eri sovellusta Nextcloud-sovelluskaupasta pilvesi muokkaamiseksi:",
    "Groupware apps like Calendar, Contacts, Mail" : "Työryhmäohjelmistot kuten kalenteri, yhteystiedot ja sähköposti",
    "Communication with Nextcloud Talk" : "Yhteydenpito Nextcloud Talkilla",
    "Collaboration apps for document editing" : "Yhteistyösovellukset asiakirjojen muokkaukseen",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Tietoturva- ja tunnistautumisominaisuuksia kuten kaksivaiheinen tunnistautuminen, kertakirjautuminen ja suoja kiristysohjelmia vastaan",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "Paljon muuta kuten musiikkisoitin, salasanahallinta, kanban-sovellus, lataushallinta ja markdown-muokkain",
    "Browse the app store" : "Selaa sovelluskauppaa",
    "Stay in sync" : "Pysy synkronoituna",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud mahdollistaa pääsyn tiedostoihisi sijainnistasi riippumatta.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Helppokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suosituimmille alustoille ilman kustannuksia!",
    "Get the apps to sync your files" : "Aseta sovellukset synkronoimaan tiedostosi",
    "Desktop client" : "Työpöytäsovellus",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "Connect your desktop apps to %s" : "Yhdistä työpöytäsovelluksesi %siin",
    "Connect your calendar" : "Yhdistä kalenteriisi",
    "Connect your contacts" : "Yhdistä yhteystietoihisi",
    "Access files via WebDAV" : "Käytä tiedostoja WebDAVin välityksellä",
    "Get help" : "Saa apua",
    "Get more information" : "Hanki lisätietoja",
    "The Nextcloud documentation for home users:" : "Nextcloud-ohjeet kotikäyttäjille:",
    "User manual" : "Käyttäjän ohje",
    "Admin manual" : "Ylläpitäjän ohje",
    "Developer manual" : "Kehittäjän ohje",
    "You can also ask for help in our community support channels:" : "Voit kysyä apua myös yhteisön tukikanavilta:",
    "the Nextcloud forums" : "Nextcloud-keskustelualueet",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloudin IRC-kanava freenode.net-verkossa",
    "Start contributing" : "Anna oma panoksesi",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Haluatko tietyn parannuksen Nextcloudiin? Löysitkö ongelman? Haluatko kääntää, mainostaa tai dokumentoida Nextcloudia?",
    "Become part of the Community" : "Ryhdy osaksi yhteisöä",
    "Enterprise support" : "Yritystuki",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Jos käytät Nextcloudia kriittisessä tuotantoympäristössä, ja palvelussa on suuri määrä käyttäjiä sekä tietoa, saatat tarvita varmuuden tuen saamisesta. Nextcloud-teknologiasta vastaavat asiantuntijat tarjoavat yritystasotilauksen pohjalta tukea sähköpostitse ja puhelimitse.",
    "Get enterprise support" : "Hanki yritystason tukea",
    "A safe home for all your data" : "Turvallinen koti kaikille tiedoillesi",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud asettaa tietosi sinun hallintaasi. Talleta asiakirjat, kalenteri, yhteystiedot ja kuvat organisaatiosi tarjoamalle palvelimelle, kotipalvelimellesi, Nextcloudin yhteistyökumppanien palvelimelle tai luottamaasi palvelinkeskukseen.",
    "Host your data and files where you decide" : "Säilytä tietosi ja tiedostosi missä itse haluat",
    "Open Standards and Interoperability" : "Avoimet standardit ja yhteentoimivuus",
    "100%% Open Source & community-focused" : "100%% avointa lähdekoodia ja yhteisökeskeisyyttä",
    "Learn more about %s" : "Lisätietoja - %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s mahdollistaa pääsyn tiedostoihisi missä hyvänsä oletkin. Hellpokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suurimmille alustoille veloituksetta.",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Määritä synkronointi käyttäen <a href=\"%s\">sovelluskohtaisia salasanoja</a>. Näin voit kumota käyttöoikeuden, jos satut esimerkiksi kadottamaan tietyn laitteesi.",
    "Connect other apps to %s" : "Yhdistä muita sovelluksia %siin",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Synkronointisovellusten lisäksi voit yhdistää minkä tahansa WebDAV-, CalDAV- ja CardDAV-yhteyskäytäntöjä tukevan ohjelmiston %siin.",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Jos haluat tukea projektia, {contributeopen}auta kehittämällä{linkclose} tai {contributeopen}levitä sanaa{linkclose}!",
    "Show First Run Wizard again" : "Näytä ensimmäisen käyttökerran avustaja uudelleen",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Käytä ja jaa tiedostoja, kalentereita, yhteystietoja, sähköpostia ja paljon muuta miltä tahansa laitteelta omilla ehdoillasi",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Lisätietoa on saatavilla <a target=\"_blank\" href=\"%s\">dokumentaatiossa</a> ja <a target=\"_blank\" href=\"%s\">verkkosivustollamme</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Jos pidät Nextcloudista, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud on mahtava avoimen lähdekoodin ohjelmisto tiedostojen synkronointiin ja jakamiseen. Voit ladata sen vapaasti osoitteesta https://nextcloud.com\">suosittele sitä ystävillesi</a> ja <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">osallistu sen kehittämiseen</a>!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/fi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Ensimmäisen käyttökerran avustaja",
    "Add your profile information! For example your email is needed to reset your password." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan salasanan palauttamiseen.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva ja koko nimi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää koko nimesi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva, jotta sinut on helpompi tunnistaa.",
    "About" : "Tietoja",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloudin ensimmäisen käyttökerran avustaja",
    "Start using Nextcloud" : "Aloita Nextcloudin käyttäminen",
    "Extend your cloud" : "Laajenna pilveäsi",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Löydä yli 100 eri sovellusta Nextcloud-sovelluskaupasta pilvesi muokkaamiseksi:",
    "Groupware apps like Calendar, Contacts, Mail" : "Työryhmäohjelmistot kuten kalenteri, yhteystiedot ja sähköposti",
    "Communication with Nextcloud Talk" : "Yhteydenpito Nextcloud Talkilla",
    "Collaboration apps for document editing" : "Yhteistyösovellukset asiakirjojen muokkaukseen",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Tietoturva- ja tunnistautumisominaisuuksia kuten kaksivaiheinen tunnistautuminen, kertakirjautuminen ja suoja kiristysohjelmia vastaan",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "Paljon muuta kuten musiikkisoitin, salasanahallinta, kanban-sovellus, lataushallinta ja markdown-muokkain",
    "Browse the app store" : "Selaa sovelluskauppaa",
    "Stay in sync" : "Pysy synkronoituna",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud mahdollistaa pääsyn tiedostoihisi sijainnistasi riippumatta.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Helppokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suosituimmille alustoille ilman kustannuksia!",
    "Get the apps to sync your files" : "Aseta sovellukset synkronoimaan tiedostosi",
    "Desktop client" : "Työpöytäsovellus",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "Connect your desktop apps to %s" : "Yhdistä työpöytäsovelluksesi %siin",
    "Connect your calendar" : "Yhdistä kalenteriisi",
    "Connect your contacts" : "Yhdistä yhteystietoihisi",
    "Access files via WebDAV" : "Käytä tiedostoja WebDAVin välityksellä",
    "Download macOS/iOS configuration profile" : "Lataa macOS-/iOS-asetusprofiili",
    "Get help" : "Saa apua",
    "Get more information" : "Hanki lisätietoja",
    "The Nextcloud documentation for home users:" : "Nextcloud-ohjeet kotikäyttäjille:",
    "User manual" : "Käyttäjän ohje",
    "Admin manual" : "Ylläpitäjän ohje",
    "Developer manual" : "Kehittäjän ohje",
    "You can also ask for help in our community support channels:" : "Voit kysyä apua myös yhteisön tukikanavilta:",
    "the Nextcloud forums" : "Nextcloud-keskustelualueet",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloudin IRC-kanava freenode.net-verkossa",
    "Start contributing" : "Anna oma panoksesi",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Haluatko tietyn parannuksen Nextcloudiin? Löysitkö ongelman? Haluatko kääntää, mainostaa tai dokumentoida Nextcloudia?",
    "Become part of the Community" : "Ryhdy osaksi yhteisöä",
    "Enterprise support" : "Yritystuki",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Jos käytät Nextcloudia kriittisessä tuotantoympäristössä, ja palvelussa on suuri määrä käyttäjiä sekä tietoa, saatat tarvita varmuuden tuen saamisesta. Nextcloud-teknologiasta vastaavat asiantuntijat tarjoavat yritystasotilauksen pohjalta tukea sähköpostitse ja puhelimitse.",
    "Get enterprise support" : "Hanki yritystason tukea",
    "A safe home for all your data" : "Turvallinen koti kaikille tiedoillesi",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud asettaa tietosi sinun hallintaasi. Talleta asiakirjat, kalenteri, yhteystiedot ja kuvat organisaatiosi tarjoamalle palvelimelle, kotipalvelimellesi, Nextcloudin yhteistyökumppanien palvelimelle tai luottamaasi palvelinkeskukseen.",
    "Host your data and files where you decide" : "Säilytä tietosi ja tiedostosi missä itse haluat",
    "Open Standards and Interoperability" : "Avoimet standardit ja yhteentoimivuus",
    "100%% Open Source & community-focused" : "100%% avointa lähdekoodia ja yhteisökeskeisyyttä",
    "Learn more about %s" : "Lisätietoja - %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s mahdollistaa pääsyn tiedostoihisi missä hyvänsä oletkin. Hellpokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suurimmille alustoille veloituksetta.",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Määritä synkronointi käyttäen <a href=\"%s\">sovelluskohtaisia salasanoja</a>. Näin voit kumota käyttöoikeuden, jos satut esimerkiksi kadottamaan tietyn laitteesi.",
    "Connect other apps to %s" : "Yhdistä muita sovelluksia %siin",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Synkronointisovellusten lisäksi voit yhdistää minkä tahansa WebDAV-, CalDAV- ja CardDAV-yhteyskäytäntöjä tukevan ohjelmiston %siin.",
    "Previous" : "Edellinen",
    "Next" : "Seuraava"
},
"nplurals=2; plural=(n != 1);");
